
<!--
FrozenIsBool False
-->

#Defaultor

##Doc
----


> 
> The Defaultor is a crucial module for understanding how we
> can manage high-computer-performance of many instanciations 
> without making the memory crashes. For an Instance that is setted
> by default, this latter will find its attributes in the 
> class __dict__. Once the instance has setted in its __dict__ a 
> special value it will stop to look at the class level. 
> There is for now no distinction of get,set for mutable or non mutable 
> variable.
> 
> 

----

<small>
View the Defaultor notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Defaultor.ipynb)
</small>

